@@ -1,12 +1,11 @@
-from __future__ import absolute_import, division, print_function
-
 import pytest
+
 import drms
 
 
-@pytest.mark.parametrize('exception_class', [
-    drms.DrmsError, drms.DrmsQueryError, drms.DrmsExportError,
-    drms.DrmsOperationNotSupported])
+@pytest.mark.parametrize(
+    'exception_class', [drms.DrmsError, drms.DrmsQueryError, drms.DrmsExportError, drms.DrmsOperationNotSupported],
+)
 def test_exception_class(exception_class):
     with pytest.raises(RuntimeError):
         raise exception_class()
